@@ -245,12 +245,6 @@ remote_desktop_show_encryption_fingerprint (CcSharingPanel *self)
   gtk_window_present (GTK_WINDOW (self->remote_desktop_fingerprint_dialog));
 }
 
-static void
-remote_desktop_hide_encryption_fingerprint (CcSharingPanel *self)
-{
-  gtk_widget_hide (self->remote_desktop_fingerprint_dialog);
-}
-
 static void
 cc_sharing_panel_class_init (CcSharingPanelClass *klass)
 {
@@ -302,7 +296,6 @@ cc_sharing_panel_class_init (CcSharingPanelClass *klass)
   gtk_widget_class_bind_template_child (widget_class, CcSharingPanel, shared_folders_listbox);
 
   gtk_widget_class_bind_template_callback (widget_class, remote_desktop_show_encryption_fingerprint);
-  gtk_widget_class_bind_template_callback (widget_class, remote_desktop_hide_encryption_fingerprint);
 
   g_type_ensure (CC_TYPE_LIST_ROW);
   g_type_ensure (CC_TYPE_HOSTNAME_ENTRY);
@@ -1045,6 +1038,11 @@ static void
 disable_gnome_remote_desktop_service (CcSharingPanel *self)
 {
   g_autoptr(GError) error = NULL;
+  g_autoptr(GSettings) rdp_settings = NULL;
+
+  rdp_settings = g_settings_new (GNOME_REMOTE_DESKTOP_RDP_SCHEMA_ID);
+
+  g_settings_set_boolean (rdp_settings, "enable", FALSE);
 
   if (!cc_disable_service (REMOTE_DESKTOP_SERVICE,
                            G_BUS_TYPE_SESSION,
